Pareto

Struct Pareto 

pub struct Pareto { /* private fields */ }
Implements the Pareto distribution

Examples

use statrs::distribution::{Pareto, Continuous};
use statrs::statistics::Distribution;
use statrs::prec;

let p = Pareto::new(1.0, 2.0).unwrap();
assert_eq!(p.mean().unwrap(), 2.0);
assert!(prec::almost_eq(p.pdf(2.0), 0.25, 1e-15));

Implementations

Source

impl Pareto

pub fn new(scale: f64, shape: f64) -> Result<Pareto, ParetoError>

Constructs a new Pareto distribution with scale scale, and shape shape.

Errors

Returns an error if any of scale or shape are NaN. Returns an error if scale <= 0.0 or shape <= 0.0

Examples
use statrs::distribution::Pareto;

let mut result = Pareto::new(1.0, 2.0);
assert!(result.is_ok());

result = Pareto::new(0.0, 0.0);
assert!(result.is_err());
pub fn scale(&self) -> f64

Returns the scale of the Pareto distribution

Examples
use statrs::distribution::Pareto;

let n = Pareto::new(1.0, 2.0).unwrap();
assert_eq!(n.scale(), 1.0);
pub fn shape(&self) -> f64

Returns the shape of the Pareto distribution

Examples
use statrs::distribution::Pareto;

let n = Pareto::new(1.0, 2.0).unwrap();
assert_eq!(n.shape(), 2.0);